@@ -2,10 +2,9 @@
 
 source "https://rubygems.org"
 
-# Specify your gem's dependencies in protocol-http1.gemspec
 gemspec
 
 group :maintenance, optional: true do
 	gem "bake-modernize"
-	gem "bake-bundler"
+	gem "bake-gem"
 end
